/**midi_editor.h is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
*/
#ifndef _MIDI_EDITOR_H_
#define _MIDI_EDITOR_H_

gboolean start_midi_editor();
void createNote(void);
void note_pressed(ClutterActor *actor, ClutterEvent *event, gpointer data);
void note_released(ClutterActor *actor, ClutterEvent *event, gpointer data);
void note_motion(ClutterActor *actor, ClutterEvent *event, gpointer data);
void grid_motion(ClutterActor *actor, ClutterEvent *event, gpointer data);

#endif /* MIDI_EDITOR_H */

